@@ -9,6 +9,7 @@
 #include <pthread.h>
 #include <sys/epoll.h>
 #include <fcntl.h>
+#include <sys/random.h>
 #include <sys/timerfd.h>
 
 #define FRAGMENT_BIT (1 << 31)
@@ -41,7 +42,9 @@ pthread_once_t gpm_init_once_control = PTHREAD_ONCE_INIT;
 static void gpm_init_once(void)
 {
     pthread_mutexattr_t attr;
-    unsigned int seedp;
+    char *buf = (char *)&gpm_global_ctx.next_xid;
+    size_t len = sizeof(gpm_global_ctx.next_xid);
+    size_t ret = 0;
 
     pthread_mutexattr_init(&attr);
     pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
@@ -52,8 +55,9 @@ static void gpm_init_once(void)
     gpm_global_ctx.epollfd = -1;
     gpm_global_ctx.timerfd = -1;
 
-    seedp = time(NULL) + getpid() + pthread_self();
-    gpm_global_ctx.next_xid = rand_r(&seedp);
+    while(ret < len) {
+        ret += getrandom(buf + ret, len - ret, 0);
+    }
 
     pthread_mutexattr_destroy(&attr);
 
@@ -121,21 +125,13 @@ done:
 
 static void gpm_close_socket(struct gpm_ctx *gpmctx)
 {
-    int ret;
-
-    do {
-        ret = close(gpmctx->fd);
-        /* in theory we should retry to close() on EINTR,
-         * but on same system the fd will be invalid after
-         * close() has been called, so closing again may
-         * cause a race with another thread that just happend
-         * to open an unrelated file descriptor.
-         * So until POSIX finally amends language around close()
-         * and at least the Linux kernel changes its behavior,
-         * it is better to risk a leak than closing an unrelated
-         * file descriptor */
-        ret = 0;
-    } while (ret == EINTR);
+    /* In theory, we should retry close() on EINTR, but the fd will be invalid
+     * after close() has been called, so closing again may cause a race with
+     * another thread that just happend to open an unrelated file descriptor.
+     * So until POSIX finally amends language around close() and at least the
+     * Linux kernel changes its behavior, it is better to risk a leak than
+     * closing an unrelated file descriptor. */
+    close(gpmctx->fd);
 
     gpmctx->fd = -1;
 }
@@ -195,6 +191,8 @@ static int gpm_epoll_setup(struct gpm_ctx *gpmctx)
     struct epoll_event ev;
     int ret;
 
+    memset(&ev, 0, sizeof(ev));
+
     if (gpmctx->epollfd >= 0) {
         gpm_epoll_close(gpmctx);
     }
@@ -276,6 +274,10 @@ static int gpm_epoll_wait(struct gpm_ctx *gpmctx, uint32_t event_flags)
     struct epoll_event events[2];
     uint64_t timer_read;
 
+    memset(&ev, 0, sizeof(ev));
+    memset(&events[0], 0, sizeof(events[0]));
+    memset(&events[1], 0, sizeof(events[1]));
+
     if (gpmctx->epollfd < 0) {
         ret = gpm_epoll_setup(gpmctx);
         if (ret)
@@ -789,4 +791,3 @@ void gpm_free_xdrs(int proc, union gp_rpc_arg *arg, union gp_rpc_res *res)
     xdr_free(gpm_xdr_set[proc].arg_fn, (char *)arg);
     xdr_free(gpm_xdr_set[proc].res_fn, (char *)res);
 }
-
