@@ -3,22 +3,53 @@
 #include "config.h"
 #include <stdbool.h>
 #include <stdlib.h>
+#include "gp_proxy.h"
 #include "gp_debug.h"
 #include "gp_log.h"
 
 /* global debug switch */
 int gp_debug = 0;
 
+
+void (*gp_debug_setup_k5_trace_fn)(int) = NULL;
+
+void gp_debug_set_krb5_tracing_fn(void (*fn)(int))
+{
+    if (gp_debug_setup_k5_trace_fn != NULL) {
+        /* deactivate potential previously set tracing
+         * facility */
+        gp_debug_setup_k5_trace_fn(0);
+    }
+
+    gp_debug_setup_k5_trace_fn = fn;
+
+    /* the tracing setup function may be set after the
+     * initial debug level is set via configuration.
+     * Make sure to immedaiately call it if debug level is
+     * already above 3 */
+    if (gp_debug >= 3 && !getenv("KRB5_TRACE")) {
+        gp_debug_setup_k5_trace_fn(1);
+    }
+}
+
 void gp_debug_toggle(int level)
 {
-    if (level <= gp_debug)
-        return;
-
-    if (level >= 3 && !getenv("KRB5_TRACE"))
-        setenv("KRB5_TRACE", "/dev/stderr", 1);
+    if (level >= 3 && !getenv("KRB5_TRACE")) {
+        if (gp_debug_setup_k5_trace_fn) {
+            gp_debug_setup_k5_trace_fn(1);
+        } else {
+            setenv("KRB5_TRACE", "/dev/stderr", 1);
+        }
+    } else if (level < 3) {
+        if (gp_debug_setup_k5_trace_fn) {
+            gp_debug_setup_k5_trace_fn(0);
+        } else {
+            unsetenv("KRB5_TRACE");
+        }
+    }
 
     gp_debug = level;
-    GPDEBUG("Debug Enabled (level: %d)\n", level);
+    GPDEBUG("Debug Level changed to %d\n", gp_debug);
 }
 
 void gp_log_failure(gss_OID mech, uint32_t maj, uint32_t min)
