@@ -9,18 +9,12 @@
 #include "gp_export.h"
 #include "gp_debug.h"
 #include "gp_proxy.h"
-#include <gssapi/gssapi_krb5.h>
 #include <pwd.h>
 #include <grp.h>
 #include <pthread.h>
 
 #define GP_CREDS_HANDLE_KEY_ENCTYPE ENCTYPE_AES256_CTS_HMAC_SHA1_96
 
-struct gp_creds_handle {
-    krb5_context context;
-    krb5_keyblock *key;
-};
-
 void gp_free_creds_handle(struct gp_creds_handle **in)
 {
     struct gp_creds_handle *handle = *in;
@@ -193,8 +187,6 @@ done:
     return ret_maj;
 }
 
-#define ENC_MIN_PAD_LEN 8
-
 /* We need to pad our payloads because krb5_c_decrypt() may pad the
  * contents for some enctypes, and gss_import_cred() doesn't like
  * having extra bytes on tokens.
@@ -300,6 +292,7 @@ static int gp_encrypt_buffer(krb5_context context, krb5_keyblock *key,
                          &data_in,
                          &enc_handle);
     if (ret) {
+        free(enc_handle.ciphertext.data);
         ret = EINVAL;
         goto done;
     }
@@ -307,13 +300,12 @@ static int gp_encrypt_buffer(krb5_context context, krb5_keyblock *key,
     ret = gp_conv_octet_string(enc_handle.ciphertext.length,
                                enc_handle.ciphertext.data,
                                out);
-    if (ret) {
-        goto done;
-    }
+    /* the conversion function copies the data, so free our copy
+     * unconditionally, or we leak */
+    free(enc_handle.ciphertext.data);
 
 done:
     free(padded);
-    free(enc_handle.ciphertext.data);
     return ret;
 }
 
