@@ -114,6 +114,11 @@ int main(int argc, const char *argv[])
     }
 
     gpctx = calloc(1, sizeof(struct gssproxy_ctx));
+    if (!gpctx) {
+        ret = EXIT_FAILURE;
+        goto cleanup;
+    }
+
     gpctx->config_file = opt_config_file;
     gpctx->config_dir = opt_config_dir;
     gpctx->config_socket = opt_config_socket;
@@ -163,7 +168,7 @@ int main(int argc, const char *argv[])
      * as nfsd needs to know GSS-Proxy is in use before the first time it
      * needs to call accept_sec_context. */
     if (!gpctx->userproxymode) {
-        init_proc_nfsd(gpctx->config);
+        init_proc_nfsd(gpctx);
     }
 
     /* Now it is safe to tell the init system that we're done starting up,
