@@ -3,8 +3,6 @@
 #include "gss_plugin.h"
 #include <gssapi/gssapi_krb5.h>
 
-#define GPKRB_SRV_NAME "Encrypted/Credentials/v1@X-GSSPROXY:"
-
 uint32_t gpp_cred_handle_init(uint32_t *min, bool defcred, const char *ccache,
                               struct gpp_cred_handle **out_handle)
 {
@@ -895,7 +893,7 @@ done:
     if (maj == GSS_S_COMPLETE) {
         *cred_handle = (gss_cred_id_t)cred;
     } else {
-        free(cred);
+        (void)gpp_cred_handle_free(&min, cred);
     }
     (void)gss_release_buffer(&min, &wrap_token);
     return maj;
