@@ -57,8 +57,8 @@ do { \
 gss_OID_set gss_mech_interposer(gss_OID mech_type);
 enum gpp_behavior gpp_get_behavior(void);
 bool gpp_is_special_oid(const gss_OID mech_type);
-const gss_OID gpp_special_mech(const gss_OID mech_type);
-const gss_OID gpp_unspecial_mech(const gss_OID mech_type);
+gss_OID gpp_special_mech(const gss_OID mech_type);
+gss_OID gpp_unspecial_mech(const gss_OID mech_type);
 gss_OID_set gpp_special_available_mechs(const gss_OID_set mechs);
 uint32_t gpp_map_error(uint32_t err);
 uint32_t gpp_unmap_error(uint32_t err);
